@@ -14,7 +14,7 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-#' Retrieve a list of all active surveys that you own on qualtrics
+#' Retrieve a data frame of all active surveys on Qualtrics
 #'
 #' @param root_url Base url for your institution (see \url{https://api.qualtrics.com/docs/root-url}. If you do not fill in anything, the function will use the default url. Using your institution-specific url can significantly speed up queries.)
 #'
@@ -38,21 +38,12 @@
 #' }
 
 getSurveys <- function(root_url = "https://yourdatacenterid.qualtrics.com") {
-
-  # Look in temporary directory. If file 'qualtRics_header.rds' does not exist, then abort and tell user to register API key first
-  f <- list.files(tempdir())
-  if(!"qualtRics_header.rds" %in% f) stop("You need to register your qualtrics API key first using the 'registerApiKey()' function.")
-
-  # Read headers information
-  headers <- readRDS(paste0(tempdir(), "/qualtRics_header.rds"))
-
+  # Check params
+  cp <- checkParams(root_url=root_url, check_qualtrics_api_key=TRUE)
   # Function-specific API stuff
-  root_url <- paste0(root_url,
-                           ifelse(substr(root_url, nchar(root_url), nchar(root_url)) == "/",
-                                  "API/v3/surveys",
-                                  "/API/v3/surveys"))
+  root_url <- appendRootUrl(root_url, "surveys")
   # Send GET request to list all surveys
-  res <- GET(root_url, add_headers(headers))
-  # Return
-  return(do.call(rbind.data.frame, content(res)$result$elements))
+  resp <- qualtricsApiRequest("GET", root_url)
+  # Bind to data frame & return
+  return(do.call(rbind.data.frame, resp$result$elements))
 }
